@@ -129,6 +129,8 @@
 #' @param counts named list of numeric vectors (one group) or matrices (>1
 #' group) containing counts for mark-resight models
 #' @param icvalues numeric vector of individual covariate values for computation of real values
+#' @param wrap if TRUE, data lines are wrapped to be length 80; if length of a row is not a 
+#'   problem set to FALSE and it will run faster
 #' @return model: a MARK object containing output and extracted results. It is
 #' a list with the following elements \item{data}{name of the processed data
 #' frame} \item{model}{type of analysis model (see list above)}
@@ -206,7 +208,7 @@ function(data,ddl=NULL,begin.time=1,model.name=NULL,model="CJS",title="",model.p
 design.parameters=list(), right=TRUE, groups = NULL, age.var = NULL, initial.ages = 0, age.unit = 1, time.intervals = NULL,nocc=NULL,output=TRUE,
 invisible=TRUE,adjust=TRUE,mixtures=1,se=FALSE,filename=NULL,prefix="mark",default.fixed=TRUE,silent=FALSE,retry=0,options=NULL,brief=FALSE,
 realvcv=FALSE,delete=FALSE,external=FALSE,profile.int=FALSE,chat=NULL,reverse=FALSE,run=TRUE,input.links=NULL,parm.specific=FALSE,mlogit0=FALSE,threads=-1,hessian=FALSE,accumulate=TRUE,
-allgroups=FALSE,strata.labels=NULL,counts=NULL,icvalues=NULL)
+allgroups=FALSE,strata.labels=NULL,counts=NULL,icvalues=NULL,wrap=TRUE)
 {
 #
 #  If the data haven't been processed (data$data is NULL) do it now with specified or default arguments
@@ -258,7 +260,7 @@ while(i<=retry & !converge)
              ddl=ddl,initial=initial,call=match.call(),default.fixed=default.fixed,
              model.name=model.name,options=options,profile.int=profile.int,chat=chat,
 			 input.links=input.links,parm.specific=parm.specific,mlogit0=mlogit0,hessian=hessian,
-			 accumulate=accumulate,icvalues=icvalues))
+			 accumulate=accumulate,icvalues=icvalues,wrap=wrap))
       if(class(model)[1]=="try-error")
 	  {
 		  stop("Misspecification of model or internal error in code")
