@@ -77,7 +77,8 @@
 #' \code{\link{create.model.list}}
 #' @keywords utility
 #' @examples 
-#' \dontrun{
+#' \donttest{
+#' # example not run to reduce time required for checking
 #' do.MSOccupancy=function()
 #' {
 #' #  Get the data
@@ -120,6 +121,11 @@ mark.wrapper.parallel<-
 #  returns a list of mark models
 #
 # -----------------------------------------------------------------------------------------------------------------------
+	if(R.Version()$os!="mingw32")
+	{
+		cat("\nWindows only function. Unable to get this function to run on non-Windows machine\n")
+		return(NULL)
+	}
 	args<-match.call()
 	t.1<-which(as.character(args[-1]) %in% ls(envir=parent.frame()))
 	t.2<-mget(as.character(args[-1][t.1]), envir=parent.frame())
@@ -172,7 +178,7 @@ mark.wrapper.parallel<-
 				model.parameters=c(model.parameters,eval(parse(text=(as.character(model.list[i,j]))),envir=parent.frame()))
 		}
 		model.name=paste(model.list[i,],collapse=".")
-		message("\n",model.name,"\n")
+		if(!silent)message("\n",model.name,"\n")
 		if(use.initial)
 		{
 			initial=NULL
