@@ -75,24 +75,26 @@ if(!is.null(derived_labels)  & cont)
 	{
 		whatread=readBin(z,raw(),16)
 		nderiv=readBin(z,integer(),1,size=4)
-		derived[[label]]=list()  
-		whatread=readBin(z,raw(),16)
-		derived[[label]]$estimate=readBin(z,numeric(),nderiv,size=8)
-		whatread=readBin(z,raw(),16)
-		derived[[label]]$se==readBin(z,numeric(),nderiv,size=8)
-		whatread=readBin(z,raw(),16)
-		derived[[label]]$lcl=readBin(z,numeric(),nderiv,size=8)
-		whatread=readBin(z,raw(),16)
-		derived[[label]]$ucl=readBin(z,numeric(),nderiv,size=8)
-		derived[[label]]=as.data.frame(derived[[label]])
-		derived.vcv[[label]]=matrix(0,nrow=nderiv,ncol=nderiv)
-		for (i in 1:nderiv)
+		if(length(nderiv)!=0)
 		{
+			derived[[label]]=list()  
 			whatread=readBin(z,raw(),16)
-			value=readBin(z,numeric(),nderiv,size=8)
-			if(length(value)!=0) derived.vcv[[label]][i,]=value
+			derived[[label]]$estimate=readBin(z,numeric(),nderiv,size=8)
+			whatread=readBin(z,raw(),16)
+			derived[[label]]$se==readBin(z,numeric(),nderiv,size=8)
+			whatread=readBin(z,raw(),16)
+			derived[[label]]$lcl=readBin(z,numeric(),nderiv,size=8)
+			whatread=readBin(z,raw(),16)
+			derived[[label]]$ucl=readBin(z,numeric(),nderiv,size=8)
+			derived[[label]]=as.data.frame(derived[[label]])
+			derived.vcv[[label]]=matrix(0,nrow=nderiv,ncol=nderiv)
+			for (i in 1:nderiv)
+			{
+				whatread=readBin(z,raw(),16)
+				value=readBin(z,numeric(),nderiv,size=8)
+				if(length(value)!=0) derived.vcv[[label]][i,]=value
+			}	
 		}
-		
 	}
 } else
 {
